==> owncloud-8.2.2p3.tgz: owncloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Permintaan pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Akses pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "Step 1 failed. Exception: %s" : "Langkah 1 gagal. Kecuali: %s",
    "Step 2 failed. Exception: %s" : "Langkah 2 gagal. Kecuali: %s",
    "External storage" : "Penyimpanan eksternal",
    "Storage with id \"%i\" not found" : "Penyimpanan dengan id \"%i\" tidak ditemukan",
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "Grant access" : "Berikan hak akses",
    "Access granted" : "Akses diberikan",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "Generate keys" : "Hasilkan kunci",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "Enable encryption" : "Aktifkan enkripsi",
    "Enable previews" : "Aktifkan pratinjau",
    "Check for changes" : "Periksa perubahan",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "Every time the filesystem is used" : "Setiap kali sistem berkas digunakan",
    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
    "(group)" : "(grup)",
    "Saved" : "Disimpan",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "OpenStack" : "OpenStack",
    "Username" : "Nama Pengguna",
    "Password" : "Sandi",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Username and password" : "Nama pengguna dan sandi",
    "Session credentials" : "Kredensial sesi",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Bagikan",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS menggunakan OC login",
    "Username as share" : "Nama pengguna berbagi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "<b>Note:</b> " : "<b>Catatan:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan cURL di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan FTP di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> \"%s\" belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "No external storage configured" : "Penyimpanan eksternal tidak dikonfigurasi",
    "You can add external storages in the personal settings" : "Anda dapat menambahkan penyimpanan eksternal di pengaturan pribadi",
    "Name" : "Nama",
    "Storage type" : "Tipe penyimpanan",
    "Scope" : "Skop",
    "External Storage" : "Penyimpanan Eksternal",
    "Folder name" : "Nama folder",
    "Authentication" : "Otentikasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Advanced settings" : "Pengaturan Lanjutan",
    "Delete" : "Hapus",
    "Add storage" : "Tambahkan penyimpanan",
    "Enable User External Storage" : "Aktifkan Penyimpanan Eksternal Pengguna",
    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/id.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Permintaan pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Akses pengambilan token gagal. Pastikan kunci dan kerahasiaan aplikasi Anda sudah benar.",
    "Please provide a valid app key and secret." : "Silakan berikan kunci dan kerahasiaan aplikasi yang benar.",
    "Step 1 failed. Exception: %s" : "Langkah 1 gagal. Kecuali: %s",
    "Step 2 failed. Exception: %s" : "Langkah 2 gagal. Kecuali: %s",
    "External storage" : "Penyimpanan eksternal",
    "Storage with id \"%i\" not found" : "Penyimpanan dengan id \"%i\" tidak ditemukan",
    "Invalid backend or authentication mechanism class" : "Beckend atau kelas mekanisme otentikasi salah.",
    "Invalid mount point" : "Mount point salah",
    "Objectstore forbidden" : "Objectstore terlarang",
    "Invalid storage backend \"%s\"" : "Backend penyimpanan \"%s\" salah",
    "Not permitted to use backend \"%s\"" : "Tidak diizinkan menggunakan backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Tidak diizinkan menggunakan mekanisme otentikasi \"%s\"",
    "Unsatisfied backend parameters" : "Parameter backend tidak lengkap",
    "Unsatisfied authentication mechanism parameters" : "Parameter mekanisme otentikasi tidak lengkap",
    "Personal" : "Pribadi",
    "System" : "Sistem",
    "Grant access" : "Berikan hak akses",
    "Access granted" : "Akses diberikan",
    "Error configuring OAuth1" : "Kesalahan mengkonfigurasi OAuth1",
    "Error configuring OAuth2" : "Kesalahan mengkonfigurasi OAuth2",
    "Generate keys" : "Hasilkan kunci",
    "Error generating key pair" : "Kesalahan saat menghasilkan pasangan kunci",
    "Enable encryption" : "Aktifkan enkripsi",
    "Enable previews" : "Aktifkan pratinjau",
    "Check for changes" : "Periksa perubahan",
    "Never" : "Jangan pernah",
    "Once every direct access" : "Setiap kali akses langsung",
    "All users. Type to select user or group." : "Semua pengguna. Ketik untuk memilih pengguna atau grup.",
    "(group)" : "(grup)",
    "Saved" : "Disimpan",
    "Username" : "Nama Pengguna",
    "Password" : "Sandi",
    "Save" : "Simpan",
    "Access key" : "Kunci akses",
    "Secret key" : "Kunci rahasia",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "OAuth1" : "OAuth1",
    "App key" : "Kunci Apl",
    "App secret" : "Rahasia Apl",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nama tenant",
    "Identity endpoint URL" : "Identitas URL akhir",
    "Rackspace" : "Rackspace",
    "API key" : "Kunci API",
    "Username and password" : "Nama pengguna dan sandi",
    "RSA public key" : "Kunci publik RSA",
    "Public key" : "Kunci Public",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Keranjang",
    "Hostname" : "Nama Host",
    "Port" : "Port",
    "Region" : "Daerah",
    "Enable SSL" : "Aktifkan SSL",
    "Enable Path Style" : "Aktifkan Gaya Path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subfolder remote",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "lokasi",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP dengan kunci rahasia masuk",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Bagikan",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS menggunakan OC login",
    "Username as share" : "Nama pengguna berbagi",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nama layanan",
    "Request timeout (seconds)" : "Minta waktu habis (detik)",
    "<b>Note:</b> " : "<b>Catatan:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan cURL di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> Dukungan FTP di PHP tidak diaktifkan atau belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Catatan:</b> \"%s\" belum diinstal. Mengaitkan %s tidak dimungkinkan. Silakan minta administrator sistem Anda untuk menginstalnya.",
    "No external storage configured" : "Penyimpanan eksternal tidak dikonfigurasi",
    "You can add external storages in the personal settings" : "Anda dapat menambahkan penyimpanan eksternal di pengaturan pribadi",
    "Name" : "Nama",
    "Storage type" : "Tipe penyimpanan",
    "Scope" : "Skop",
    "External Storage" : "Penyimpanan Eksternal",
    "Folder name" : "Nama folder",
    "Authentication" : "Otentikasi",
    "Configuration" : "Konfigurasi",
    "Available for" : "Tersedia untuk",
    "Add storage" : "Tambahkan penyimpanan",
    "Advanced settings" : "Pengaturan Lanjutan",
    "Delete" : "Hapus",
    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=1; plural=0;");
